from .roulette import Roulette
from .errors import ItemNotFound, PlayerNotFound
from .user import User
from .shop import shop
from .utils import utils

__all__ = ['Roulette', 'ItemNotFound', 'PlayerNotFound', 'User', 'Shop', 'Utils']



import requests
from .errors import PlayerNotFound

class User:
    def __init__(self, data: dict, key: str):
        self.name: str = key
        self.obtained: int = data[key]
        self.id: int = None
        self.roles: str = None
        self.tags: str = None
        self.rank: int = None
        self.wager: int = None
        self.wins: int = None
        self.losses: int = None

    def __str__(self):
        return self.name

    def player(self, id):
        request = requests.get(f'https://api.rbxflip.com/users/{id}').json()
        if request['success']:
            self.id = id
            self.name = request['name']
            self.roles = request['roles']
            self.tags = request['tags']
            self.rank = request['rank']
        else:
            raise PlayerNotFound(f'Player {id} does not exist')

    def wager(self, period=0):
        url = f'https://api.rbxflip.com/wagers/users/{self.id}/stats?period={period}'
        request = requests.get(url).json()
        if request['success']:
            self.wager = request['total_wagers']
            self.wins = request['total_wins']
            self.losses = request['total_losses']
        else:
            raise Exception('Error retrieving wager stats')



import requests
from .errors import ItemNotFound

class shop:
    def __init__(self, id: int):
        self.id = id
        self.data = self.get_item_data()

    def __str__(self):
        return self.name

    def get_item_data(self):
        request = requests.get(f'https://api.rbxflip.com/roblox/shop').json()
        if request['success']:
            for item in request['data']:
                if item['id'] == self.id:
                    return item
            raise ItemNotFound(f'Item {self.id} does not exist')
        else:
            raise ItemNotFound(f'Item {self.id} does not exist')

    @property
    def name(self):
        return self.data['name']

    @property
    def rate(self):
        return self.data['rate']

    @property
    def price(self):
        return self.data['price']

    @property
    def rap(self):
        return self.data['value']


    @property
    def sellerid(self):
        return self.data['sellerid']
    
    @property
    def serial(self):
        return self.data['serial']
    
    @property
    def projected(self):
        return self.data['projected']


import requests
from bs4 import BeautifulSoup

class utils:
    def __init__(self):
        self.cli = requests.Session()

    def getshopitem(self):
        return self.cli.get('https://api.rbxflip.com/roblox/shop').json()

    def checkuser(self, user_id):
        players = []
        try:
            request = self.cli.get(f'https://api.rbxflip.com/users/{user_id}')
            soup = BeautifulSoup(request.text, 'html.parser')
            player_meta = soup.find_all('div', attrs={'class': 'pb-2 mb-3 item_cell shadow_md_35 shift_up_md mx-0'})
            for i, p in enumerate(player_meta):
                player_soup = BeautifulSoup(str(p), 'html.parser')
                username = player_soup.find('h6', attrs={'class': 'my-0 px-2 text-light py-1 text-truncate'}).get_text()
                value_data = [user.get_text().replace('R$ ', '') for user in player_soup.find_all('span', attrs={'class': 'text-truncate'})[1:]]
                user_stats = self.getuserstats(user_id)
                players.append(user([i+1, username, value_data[0], value_data[1], user_stats['total_wagers'], user_stats['total_wins'], user_stats['total_losses']]))
        except Exception as e:
            print(f"Error fetching players: {str(e)}")
        return players
    
    def getuserstats(self, user_id):
        stats = self.cli.get(f'https://api.rbxflip.com/wagers/users/{user_id}/stats?period=0').json()
        return [        
            stats['wagers']['total_wagers'],
            stats['wagers']['total_wins'],
            stats['wagers']['total_losses']
        ]

class user:
    def __init__(self, data: list):
        self.rank: int = data[6]
        self.name: str = data[5]
        self.display: int = data[8]
        self.wager: int = data[2]
        self.profit: int = data[3]
        self.total_losses: int = data[4]



import requests

class Roulette:
    def __init__(self, data: dict):
        self.round = data['round']
        self.id = data['id']
        self.players = data['players']
        self.client_seed = data['clientSeed']

    def __str__(self):
        return f"Round: {self.round}\nID: {self.id}\nPlayers: {self.players}\nClient Seed: {self.client_seed}"

def get_roulette():
    r = requests.get('https://api.rbxflip.com/games/roulette').json()
    return Roulette(r)



from setuptools import setup

setup(
    name='rbxflip',
    version='1.0.3',
    description='Python package for interacting with the RBXFlip API',
    author='Angelics',
    url='https://github.com/Angelics9999/rbxflip',
    packages=['rbxflip'],
    install_requires=['requests'],
)
